@@ -30,7 +30,7 @@ pub use self::login::Login;
 pub use self::state::{
     Condition, CreateStateDto, CreateStateLocationAwsDto, CreateStateLocationAzureDto,
     CreateStateLocationsDto, ProvisioningStatus, State, StateLocationAws, StateLocationAzure,
-    StateLocationStatus, StateLocations, StateName,
+    StateLocationStatus, StateLocations, StateName, StorageClass,
 };
 pub use self::volume::{
     CreateVolumeDto, LocationVolumeStatus, StateLocationVolumeProgress, Volume, VolumeBindingMode,
